@@ -597,7 +597,7 @@ def coriolis_parameter(latitude):
 
     Parameters
     ----------
-    latitude : array_like
+    latitude : array-like
         Latitude at each point
 
     Returns
@@ -625,6 +625,13 @@ def add_height_to_pressure(pressure, height):
     height : `pint.Quantity`
         Height above a pressure level
 
+    Examples
+    --------
+    >>> from metpy.calc import add_height_to_pressure
+    >>> from metpy.units import units
+    >>> add_height_to_pressure(1000 * units.hPa, 500 * units.meters)
+    <Quantity(941.953016, 'hectopascal')>
+
     Returns
     -------
     `pint.Quantity`
@@ -659,6 +666,13 @@ def add_pressure_to_height(height, pressure):
     `pint.Quantity`
         The corresponding height value for the pressure above the height level
 
+    Examples
+    --------
+    >>> from metpy.calc import add_pressure_to_height
+    >>> from metpy.units import units
+    >>> add_pressure_to_height(1000 * units.meters, 100 * units.hPa)
+    <Quantity(1.96117548, 'kilometer')>
+
     See Also
     --------
     pressure_to_height_std, height_to_pressure_std, add_height_to_pressure
@@ -676,7 +690,7 @@ def sigma_to_pressure(sigma, pressure_sfc, pressure_top):
 
     Parameters
     ----------
-    sigma : ndarray
+    sigma : numpy.ndarray
         Sigma levels to be converted to pressure levels
 
     pressure_sfc : `pint.Quantity`
@@ -690,6 +704,15 @@ def sigma_to_pressure(sigma, pressure_sfc, pressure_top):
     `pint.Quantity`
         Pressure values at the given sigma levels
 
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from metpy.calc import sigma_to_pressure
+    >>> from metpy.units import units
+    >>> sigma_levs = np.linspace(0, 1, 10)
+    >>> sigma_to_pressure(sigma_levs, 1000 * units.hPa, 10 * units.hPa)
+    <Quantity([  10.  120.  230.  340.  450.  560.  670.  780.  890. 1000.], 'hectopascal')>
+
     Notes
     -----
     Sigma definition adapted from [Philips1957]_:
@@ -819,7 +842,7 @@ def smooth_window(scalar_grid, window, passes=1, normalize_weights=True):
     scalar_grid : array-like
         N-dimensional scalar grid to be smoothed
 
-    window : ndarray
+    window : numpy.ndarray
         Window to use in smoothing. Can have dimension less than or equal to N. If
         dimension less than N, the scalar grid will be smoothed along its trailing dimensions.
         Shape along each dimension must be odd.
@@ -910,7 +933,7 @@ def smooth_rectangular(scalar_grid, size, passes=1):
     scalar_grid : array-like
         N-dimensional scalar grid to be smoothed
 
-    size : int or sequence of ints
+    size : int or Sequence[int]
         Shape of rectangle along the trailing dimension(s) of the scalar grid
 
     passes : int
@@ -1050,7 +1073,7 @@ def zoom_xarray(input_field, zoom, output=None, order=3, mode='constant', cval=0
     input_field  : `xarray.DataArray`
         The 2D data array to be interpolated.
 
-    zoom : float or sequence
+    zoom : float or Sequence[float]
         The zoom factor along the axes. If a float, zoom is the same for each axis. If a
         sequence, zoom should contain one value for each axis.
 
@@ -1058,15 +1081,15 @@ def zoom_xarray(input_field, zoom, output=None, order=3, mode='constant', cval=0
         The order of the spline interpolation, default is 3. The order has to be in the
         range 0-5.
 
-    mode : {‘reflect’, ‘grid-mirror’, ‘constant’, ‘grid-constant’, ‘nearest’, ‘mirror’,
-        ‘grid-wrap’, ‘wrap’}, optional
+    mode : str, optional
+        One of {'reflect', 'grid-mirror', 'constant', 'grid-constant', 'nearest', 'mirror',
+        'grid-wrap', 'wrap'}. See `scipy.ndimage.zoom` documentation for details.
+
+    cval : float or int, optional
         See `scipy.ndimage.zoom` documentation for details.
 
-    cval : scalar, optional
-        See `scipy.ndimage.zoom` documentation for details.
-
-    prefilter : bool (default = True)
-        See `scipy.ndimage.zoom` documentation for details.
+    prefilter : bool, optional
+        See `scipy.ndimage.zoom` documentation for details. Defaults to `True`.
 
     Returns
     -------
@@ -1156,7 +1179,7 @@ def altimeter_to_station_pressure(altimeter_value, height):
     gamma = lapse rate in [NOAA1976]_ standard atmosphere below the isothermal layer
     :math:`6.5^{\circ}C. km.^{-1}`
 
-    :math:`t_{0}` = standard sea-level temperature 288 K
+    :math:`T_{0}` = standard sea-level temperature 288 K
 
     :math:`H_{b} =` station elevation in meters (elevation for which station pressure is given)
 
@@ -1201,19 +1224,19 @@ def altimeter_to_sea_level_pressure(altimeter_value, height, temperature):
 
     Parameters
     ----------
-    altimeter_value : 'pint.Quantity'
+    altimeter_value : `pint.Quantity`
         The altimeter setting value is defined by the METAR or other observation,
         with units of inches of mercury (in Hg) or millibars (hPa).
 
-    height  : 'pint.Quantity'
+    height  : `pint.Quantity`
         Elevation of the station measuring pressure. Often times measured in meters
 
-    temperature : 'pint.Quantity'
+    temperature : `pint.Quantity`
         Temperature at the station
 
     Returns
     -------
-    'pint.Quantity'
+    `pint.Quantity`
         The sea-level pressure in hPa and makes pressure values easier to compare
         between different stations.
 
