@@ -49,16 +49,23 @@ class CFProjection:
         if 'earth_radius' in self._attrs:
             kwargs = {'ellipse': 'sphere', 'semimajor_axis': self._attrs['earth_radius'],
                       'semiminor_axis': self._attrs['earth_radius']}
+
         else:
             attr_mapping = [('semimajor_axis', 'semi_major_axis'),
                             ('semiminor_axis', 'semi_minor_axis'),
                             ('inverse_flattening', 'inverse_flattening')]
             kwargs = self._map_arg_names(self._attrs, attr_mapping)
 
-            # WGS84 with semi_major==semi_minor is NOT the same as spherical Earth
-            # Also need to handle the case where we're not given any spheroid
+            # Override CartoPy's default ellipse setting depending on whether
+            # we have any metadata to map about the spheroid.
             kwargs['ellipse'] = None if kwargs else 'sphere'
 
+        # interpret the 0 inverse_flattening as a spherical datum
+        # and don't pass the value on.
+        if kwargs.get('inverse_flattening', None) == 0:
+            kwargs['ellipse'] = 'sphere'
+            kwargs.pop('inverse_flattening', None)
+
         return ccrs.Globe(**kwargs)
 
     @property
